
import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_root_dir


def reset_password():
  """
  Usage: <main class> resetpassword
  Reset password for localhost
  """
  download_geoweaver_jar()
  subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "resetpassword",])




"""
The main function of pygeoweaver
To run in CLI mode. 
"""
from pygeoweaver import detail_host, detail_process, detail_workflow, export_workflow, \
    show_history, import_workflow, list_hosts, list_processes, list_workflows, \
    start, stop, reset_password, run_process, run_worklfow

def main():
    # start geoweaver
    start()
    # stop geoweaver
    # stop()
    # list resources
    #list_hosts()
    #list_processes()
    # list_workflows()
    # show history
    #show_history("ll3u3W78eOEfklxhBJ")
    # detail host
    # detail_host("100001")
    # detail process
    # detail_process("7pxu8c")
    #detail_workflow("5jnhcrq33znbu2mue9v2")
    # import workflow
    #import_workflow("/Users/joe/Downloads/gr3ykr8dynu12vrwq11oy.zip")
    # export workflow
    # export_workflow("gr3ykr8dynu12vrwq11oy", "4", "/Users/joe/Downloads/test_pygeoweaver_export.zip")
    # run process
    # run_process(process_id="7zwnvx", host_id="100001", password="xxx", environment="",)
    # run workflow by id
    # run_worklfow(workflow_id="9sszomwhiiusakodb1ft", host_list="100001", password_list="xxx", 
    #              environment_list="",)
    # run workflow by zip path

    # run workflow by folder path

    # reset localhost password for Geoweaver
    # reset_password()


if __name__ == "__main__":
     main()


"""
The main function of pygeoweaver
To run in CLI mode. 
"""
from pygeoweaver import detail_host, detail_process, detail_workflow
from pygeoweaver import export_workflow
from pygeoweaver import show_history
from pygeoweaver import import_workflow
from pygeoweaver import list_hosts, list_processes, list_workflows
from pygeoweaver import start, stop

import unittest

class Testing(unittest.TestCase):

    def test_main():
        # start geoweaver
        #start()
        # stop geoweaver
        # stop()
        # list resources
        #list_hosts()
        #list_processes()
        list_workflows()
        # show history
        #show_history("ll3u3W78eOEfklxhBJ")
        # detail host
        # detail_host("100001")
        # detail process
        # detail_process("7pxu8c")
        #detail_workflow("5jnhcrq33znbu2mue9v2")
        # import workflow
        #import_workflow("/Users/joe/Downloads/gr3ykr8dynu12vrwq11oy.zip")
        # export workflow
        export_workflow("gr3ykr8dynu12vrwq11oy", "4", "/Users/joe/Downloads/test_pygeoweaver_export.zip")


if __name__ == "__main__":
    unittest.main()


import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_root_dir


def run_process(*, process_id: str, host_id: str, password: str, environment: str=None):
    """
    Run a process

    Args: process_id - required
        host_id - required
        password - required
        environment - optional
    """
    download_geoweaver_jar()
    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "run", "process", f"--host={host_id}",
                    f"--password={password}", f"--environment={environment}", process_id],
                   cwd=f"{get_root_dir()}/")

def run_worklfow(*, workflow_id: str, workflow_folder_path: str=None, workflow_zip_file_path: str=None, 
                 environment_list: str=None, host_list: str, password_list: str):
    """
    Usage: <main class> run workflow [-d=<workflowFolderPath>]
                                    [-f=<workflowZipPath>] [-e=<envs>]...
                                    [-h=<hostStrings>]... [-p=<passes>]...
                                    <workflowId>
        <workflowId>           workflow id to run
    -d, --workflow-folder-path=<workflowFolderPath>
                                geoweaver workflow folder path
    -e, --environments=<envs>  environments to run on. List of environment ids with comma as separator
    -f, --workflow-zip-file-path=<workflowZipPath>
                                workflow package or path to workflow zip to run
    -h, --hosts=<hostStrings>  hosts to run on. list of host ids with comma as separator.
    -p, --passwords=<passes>   passwords to the target hosts. list of passwords with comma as separator. 
    """
    download_geoweaver_jar()

    if not workflow_id and not workflow_folder_path and not workflow_zip_file_path:
        raise RuntimeError("Please provide at least one of the three options: workflow id, " \
                           "folder path or zip path")
    
    if workflow_id and not workflow_folder_path and not workflow_zip_file_path:
        subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "run", "workflow", workflow_id,
                        "-e", environment_list,
                        "-h", host_list,
                        "-p", password_list],
                       cwd=f"{get_root_dir()}/")

    if workflow_folder_path and not workflow_zip_file_path:
        # command to run workflow from folder
        subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "run", "workflow", workflow_id,
                        "-d", workflow_folder_path,
                        "-e", environment_list,
                        "-h", host_list,
                        "-p", password_list],
                       cwd=f"{get_root_dir()}/")

    if not workflow_folder_path and workflow_zip_file_path:
        subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "run", "workflow", workflow_id,
                        "-e", environment_list,
                        "-f", workflow_zip_file_path,
                        "-h", host_list,
                        "-p", password_list],
                       cwd=f"{get_root_dir()}/")
        



import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_root_dir


def list_hosts():
    download_geoweaver_jar()
    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "list", "--host"], cwd=f"{get_root_dir()}/")


def list_processes():
    download_geoweaver_jar()
    subprocess.run(["chmod", "+x", get_geoweaver_jar_path()], cwd=f"{get_root_dir()}/")
    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "list", "--process"], cwd=f"{get_root_dir()}/")


def list_workflows():
    download_geoweaver_jar()
    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "list", "--workflow"], cwd=f"{get_root_dir()}/")




import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_root_dir


def export_workflow(workflow_id, mode, target_file_path):
    """
    Usage: <main class> export workflow [--mode=<export_mode>] <workflow_id>
                                    <target_file_path>
      <workflow_id>          Geoweaver workflow ID
      <target_file_path>     target file path to save the workflow zip
      --mode=<export_mode>   exportation model options:
                                1 - workflow only
                                2 - workflow with process code
                                3 - workflow with process code and only good
                               history
                                4 - workflow with process code and all the
                               history.default option is 4.
    """
    if not workflow_id:
        raise RuntimeError("Workflow id is missing")
    download_geoweaver_jar()
    subprocess.run(["java", "-jar", get_geoweaver_jar_path(), "export", "workflow", 
                    f"--mode={mode}", workflow_id, target_file_path,], 
                   cwd=f"{get_root_dir()}/")


import os
import subprocess
import requests
import platform

def get_home_dir():
    return os.path.expanduser('~')


def get_root_dir():
    head, tail = os.path.split(__file__)
    return head


def get_geoweaver_jar_path():
    return f"{get_home_dir()}/geoweaver.jar"


def check_geoweaver_jar():
    return os.path.isfile(get_geoweaver_jar_path())


def download_geoweaver_jar(overwrite=False):
    if check_geoweaver_jar():
        if overwrite:
            os.remove(get_geoweaver_jar_path())
        else:
            subprocess.run(["chmod", "+x", get_geoweaver_jar_path()], cwd=f"{get_root_dir()}/")
            return

    geoweaver_url = "https://github.com/ESIPFed/Geoweaver/releases/download/latest/geoweaver.jar"
    r = requests.get(geoweaver_url)

    with open(get_geoweaver_jar_path(), 'wb') as f:
        f.write(r.content)

    if check_geoweaver_jar():
        print("Geoweaver.jar is downloaded")

    else:
        raise RuntimeError("Fail to download geoweaver.jar")


def checkOS():
    if platform.system() == "Linux" or platform == "Linux2":
        return 1
    elif platform.system() == "Darwin":
        return 2
    elif platform == "Windows":
        return 3


import os
import subprocess
from pygeoweaver.utils import checkOS, download_geoweaver_jar, get_root_dir

"""
This module provides function to start and stop Geoweaver server.
If it detects the current environment is Jupyter notebook, it will 
open Geoweaver GUI in the output cell (if gui is not disabld.)

"""


def start(force=False):
    download_geoweaver_jar(overwrite=force)
    if checkOS() == 3:
        raise RuntimeError("windows is not supported yet")
    else:
        result = subprocess.run(['./start.sh'], cwd=f"{get_root_dir()}/")
    


def stop():
    if checkOS() == 3:
        raise RuntimeError("Windows is not supported yet")
    else:
        result = subprocess.run(['./stop.sh'], cwd=f"{get_root_dir()}/", shell=True)
    




